Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code | Sign in
(40)

Unified Diff: state/api/provisioner/provisioner.go

Issue 96140044: Introduce lxc-use-clone, ContainerManagerConfig
Patch Set: Introduce lxc-use-clone, ContainerManagerConfig Created 9 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Please Sign in to add in-line comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « state/api/params/params.go ('k') | state/api/provisioner/provisioner_test.go » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: state/api/provisioner/provisioner.go
=== modified file 'state/api/provisioner/provisioner.go'
--- state/api/provisioner/provisioner.go 2014-04-12 05:53:58 +0000
+++ state/api/provisioner/provisioner.go 2014-05-09 01:52:58 +0000
@@ -115,7 +115,14 @@
return result.Tools, nil
}
-// ContainerConfig returns information from the environment config that are
+// ContainerManagerConfig returns information from the environment config that is
+// needed for configuring the container manager.
+func (st *State) ContainerManagerConfig(args params.ContainerManagerConfigParams) (result params.ContainerManagerConfig, err error) {
+ err = st.call("ContainerManagerConfig", args, &result)
+ return result, err
+}
+
+// ContainerConfig returns information from the environment config that is
// needed for container cloud-init.
func (st *State) ContainerConfig() (result params.ContainerConfig, err error) {
err = st.call("ContainerConfig", nil, &result)
« no previous file with comments | « state/api/params/params.go ('k') | state/api/provisioner/provisioner_test.go » ('j') | no next file with comments »

Powered by Google App Engine
RSS Feeds Recent Issues | This issue
This is Rietveld f62528b